from __future__ import annotations
from enum import Enum
from typing import Dict, List, Any

from pydantic import BaseModel, Field

import pprint
import re  # noqa: F401
import json


class Function(BaseModel):
    name: str = Field(..., title="function名", description="function名")
    description: str = Field(..., title="function描述", description="function描述")
    parameters: Dict = Field(..., title="function参数定义", description="function参数定义，json schema格式")

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Function:
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Function:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Function.parse_obj(obj)

        _obj = Function.parse_obj({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "parameters": obj.get("parameters")
        })
        return _obj


class FunctionChoiceType(Enum):
    none = "none"
    auto = "auto"
    specific = "specific"


class FunctionChoice(BaseModel):
    type: FunctionChoiceType = Field(..., title="function调用策略", description="function调用策略")
    names: List[str] = Field(None, title="指定的 function 名", description="调用策略为specific时指定的function名，目前只生效第一个")

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FunctionChoice:
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FunctionChoice:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FunctionChoice.parse_obj(obj)

        _obj = FunctionChoice.parse_obj({
            "type": obj.get("type"),
            "names": obj.get("names")
        })
        return _obj


class PlanningApiInfo(BaseModel):
    api_name: str = Field(..., alias="apiName", description="fc名称")
    parameters: Dict = Field({})

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PlanningApiInfo:
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PlanningApiInfo:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PlanningApiInfo.parse_obj(obj)

        _obj = PlanningApiInfo.parse_obj({
            "api_name": obj.get("apiName"),
            "parameters": obj.get("parameters")
        })
        return _obj


class FunctionCall(BaseModel):
    thought: str = Field(...)
    api_call_list: List[PlanningApiInfo] = Field([], alias="apiCallList", description="API调用列表")

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FunctionCall:
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FunctionCall:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FunctionCall.parse_obj(obj)

        _obj = FunctionCall.parse_obj({
            "thought": obj.get("thought"),
            "api_call_list": [PlanningApiInfo.from_dict(_item) for _item in obj.get("apiCallList")] if obj.get("apiCallList") is not None else None,

        })
        return _obj


class Plugin(BaseModel):
    name: str = Field(..., title="插件名", description="插件名")
    ext: Dict = Field(None, title="插件参数", description="插件参数")

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Plugin:
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Plugin:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Plugin.parse_obj(obj)

        _obj = Plugin.parse_obj({
            "name": obj.get("thought"),
            "ext": obj.get("ext")

        })
        return _obj



# coding: utf-8

import json
from typing import Optional

from pydantic import BaseModel, Field, StrictStr


class GroupChatReplySetting(BaseModel):
    bot_name: StrictStr = Field(..., alias="botName", description="回复角色名称，必须为群聊角色中的一名角色")
    thought: Optional[StrictStr] = Field(None, alias="thought", description="希望角色如何回复")

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        # 直接使用 json.dumps 序列化，提高性能效率
        return json.dumps(self.dict(by_alias=True, exclude_none=True), indent=4)

    def to_json(self) -> str:
        # 同样，直接序列化，避免不必要的中间步骤
        return json.dumps(self.dict(by_alias=True, exclude_none=True))

    @classmethod
    def from_json(cls, json_str: str) -> 'GroupChatReplySetting':
        # 增加异常处理来确保输入的 JSON 字符串是有效的
        try:
            obj_dict = json.loads(json_str)
            return cls.from_dict(obj_dict)
        except json.JSONDecodeError:
            raise ValueError("Invalid JSON string")

    def to_dict(self):
        # 简化了代码风格
        return self.dict(by_alias=True, exclude_none=True)

    @classmethod
    def from_dict(cls, obj: dict) -> 'GroupChatReplySetting':
        # 移除了对 `obj` 是否为 `None` 的判断，因为 `parse_obj` 已经能够处理 `None` 的情况
        # 同时，明确使用 `cls.__init__` 来创建实例，提高代码的可维护性和健壮性
        if not isinstance(obj, dict):
            raise TypeError("Expected a dictionary object")

        return cls(bot_name=obj.get("botName"), thought=obj.get("thought"))


import json
import pprint
from typing import Dict, Optional, Any

from pydantic import BaseModel, Field, conlist, StrictStr, StrictFloat, StrictInt, StrictBool

from xingchen import AcAReqMessage, AcAReqTool


class AcACompletionReq(BaseModel):
    """
    completions 接口请求参数
    """
    messages: conlist(AcAReqMessage) = Field(..., description="""
    A list of messages comprising the conversation so far.
    Contain system message, user message, assistant message and tool message.
    """)
    model: StrictStr = Field(..., description="""
    xingchen model name, such as xingchen-plus
    """)
    max_tokens: Optional[StrictInt] = Field(None, alias="max_tokens", description="""
    The maximum number of tokens that can be generated in the chat completion.
    """)
    seed: Optional[StrictInt] = Field(None, description="""
    If specified, our system will make a best effort to sample deterministically, 
    such that repeated requests with the same seed and parameters should return the same result. 
    """)
    stream: Optional[StrictBool] = Field(None, description="""
    If set, partial message deltas will be sent,
    Tokens will be sent as data-only server-sent events as they become available, with the stream terminated by a event: stop
    """)
    temperature: Optional[StrictFloat] = Field(None, description="""
    Between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic.
    We generally recommend altering this or top_p but not both.
    """)
    top_p: Optional[StrictFloat] = Field(None, description="""
    An alternative to sampling with temperature, called nucleus sampling, 
    where the model considers the results of the tokens with top_p probability mass. 
    So 0.1 means only the tokens comprising the top 10% probability mass are considered.
    """)
    tools: Optional[conlist(AcAReqTool)] = Field(None, description="""
    A list of tools the model may call. Currently, only functions are supported as a tool. 
    Use this to provide a list of functions the model may generate JSON inputs for. A max of 128 functions are supported.
    """)
    tool_choice: Optional[Any] = Field(None, alias="tool_choice", description="""
    Controls which (if any) tool is called by the model. 
    none means the model will not call any tool and instead generates a message. 
    auto means the model can pick between generating a message or calling one or more tools. 
    required means the model must call one or more tools. 
    Specifying a particular tool via {"type": "function", "function": {"name": "my_function"}} forces the model to call that tool.
    """)
    user: Optional[StrictStr] = Field(..., description="用户标识")

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> 'AcACompletionReq':
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> 'AcACompletionReq':
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.parse_obj(obj)

        _obj = cls.parse_obj({
            "messages": obj.get("messages"),
            "model": obj.get("model"),
            "max_tokens": obj.get("max_tokens"),
            "seed": obj.get("seed"),
            "stream": obj.get("stream"),
            "top_p": obj.get("top_p"),
            "tools": obj.get("tools"),
            "tool_choice": obj.get("tool_choice"),
            "user": obj.get("user"),
        })
        return _obj



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from xingchen.models.chat_history_query_where import ChatHistoryQueryWhere
from xingchen.models.gateway_issued_params import GatewayIssuedParams

class ChatHistoryQueryDTO(BaseModel):
    """
    聊天历史查询对象  # noqa: E501
    """
    where: Optional[ChatHistoryQueryWhere] = None
    order_by: Optional[conlist(StrictStr)] = Field(None, alias="orderBy", description="排序条件，支持的排序字段为： - gmtCreate 排序优先级按列表顺序，默认降序，如果期望升序，需要在字段后指定，如：orderBy: [\\\"gmtCreate desc\\\"] （gmtCreate 按降序） ")
    page_num: Optional[StrictInt] = Field(None, alias="pageNum", description="页码，默认为 0")
    page_size: Optional[StrictInt] = Field(None, alias="pageSize", description="页条目数，1～50，默认为 10")
    __properties = ["where", "orderBy", "pageNum", "pageSize"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChatHistoryQueryDTO:
        """Create an instance of ChatHistoryQueryDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of where
        if self.where:
            _dict['where'] = self.where.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChatHistoryQueryDTO:
        """Create an instance of ChatHistoryQueryDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatHistoryQueryDTO.parse_obj(obj)

        _obj = ChatHistoryQueryDTO.parse_obj({
            "where": ChatHistoryQueryWhere.from_dict(obj.get("where")) if obj.get("where") is not None else None,
            "order_by": obj.get("orderBy"),
            "page_num": obj.get("pageNum"),
            "page_size": obj.get("pageSize")
        })
        return _obj





from xingchen.models import ChatReqParams, BaseChatRequest, Input
from xingchen.models.custom import ChatResponse, ChatResult
from xingchen.models.custom.completion.completion_resp import AcACompletionResp

from sseclient import SSEClient
import json

api_router_map = {
    '/v2/api/chat/send': 'aca-chat-send',
    '/v2/api/groupchat/send': 'aca-groupchat-send',
    '/v2/api/character/create': 'aca-character-create',
    '/v2/api/character/update': 'aca-character-update',
    '/v2/api/character/details': 'aca-character-details',
    '/v2/api/character/delete': 'aca-character-delete',
    '/v2/api/character/search': 'aca-character-search',
    '/v2/api/character/createOrUpdateVersion': 'aca-character-version-mgmt',
    '/v2/api/character/versions': 'aca-character-versions',
    '/v2/api/character/newversion/recommend': 'aca-character-version-recommend',
    '/v2/api/chat/message/histories': 'aca-message-history',
    '/v2/api/chat/rating': 'aca-message-rating',
    '/v2/api/chat/reminder': 'aca-chat-reminder',
    '/v2/api/chat/reset': 'aca-chat-reset',
    '/v2/api/extract/kv': 'aca-extract-memory-kv',
    '/v2/api/extract/summary': 'aca-extract-memory-summary',
    '/v2/api/character/auto/desc': 'aca-char-auto-desc',
    '/v2/api/chat/polling/image': 'aca-polling-image',
    '/v2/api/chat/stop': 'aca-chat-stop',
    '/v2/api/common/file/asyn/upload': 'aca-doc-converter-submit',
    '/v2/api/common/file/asyn/download': 'aca-doc-converter-result',
    '/v2/api/completions': 'aca-completion',
}


def get_service_router(path, async_req):
    if not path:
        return None
    if path.__eq__('/v2/api/chat/send') and async_req:
        return 'aca-chat-send-sse'
    if path.__eq__('/v2/api/groupchat/send') and async_req:
        return 'aca-groupchat-send-sse'
    return api_router_map.get(path)


def convert_chat_params(chat_req_params: ChatReqParams):
    bot_profile = chat_req_params.bot_profile
    parameters = chat_req_params.model_parameters
    user_profile = chat_req_params.user_profile
    scenario = chat_req_params.scenario
    messages = chat_req_params.messages
    sample_messages = chat_req_params.sample_messages
    model_name = parameters.model_name if parameters is not None else None
    functions = chat_req_params.functions
    plugins = chat_req_params.plugins
    function_choice = chat_req_params.function_choice
    context = chat_req_params.context
    memory = chat_req_params.memory

    aca = {
        'botProfile': bot_profile,
        'userProfile': user_profile,
        'sampleMessages': sample_messages,
        'scenario': scenario,
        'functionList': functions,
        'pluginList': plugins,
        'functionChoice': function_choice,
        'context': context,
        'memory': memory
    }

    return BaseChatRequest(
        model=model_name,
        input=Input(
            prompt='|<system>|',
            messages=messages,
            aca=aca
        ),
        parameters=parameters
    )


def handle_sse_response(client: SSEClient):
    events = client.events()
    for event in events:
        d = json.loads(event.data)
        error_code = d.get('errorCode', None)
        if error_code is not None:
            yield ChatResponse.from_dict(d)
            return
        yield ChatResponse(
            success=True,
            http_status_code=200,
            code=200,
            data=ChatResult.from_dict(d)
        )


def handle_completion_sse_response(client: SSEClient):
    events = client.events()
    for event in events:
        d = json.loads(event.data)
        error_code = d.get('errorCode', None)
        if error_code is not None:
            yield ChatResponse.from_dict(d)
            return
        yield AcACompletionResp.from_dict(d)



from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic import BaseModel, Field, StrictStr, StrictBool, conlist

from xingchen.models.kv_memory_config import KVMemoryConfig


class LongTermMemory(BaseModel):
    enabled: Optional[StrictBool] = Field(None, description="是否启动")
    memory_type: Optional[StrictStr] = Field(None, alias="memoryType", description="记忆类型")
    kv_memory_configs: Optional[conlist(KVMemoryConfig)] = Field(None, alias="kvMemoryConfigs",
                                                                 description="kv记忆配置,当memoryType为kv时生效")
    __properties = ["enabled", "memoryType", "kvMemoryConfigs"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LongTermMemory:
        """Create an instance of LongTermMemory from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LongTermMemory:
        """Create an instance of LongTermMemory from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return KVMemoryConfig.parse_obj(obj)

        _obj = KVMemoryConfig.parse_obj({
            "enabled": obj.get("enabled"),
            "memory_type": obj.get("memoryType"),
            "kv_memory_configs": [KVMemoryConfig.from_dict(_item) for _item in obj.get("kvMemoryConfigs")] if obj.get(
                "kvMemoryConfigs") is not None else None
        })
        return _obj



import json
import pprint

from pydantic import Field, conlist

from xingchen.models.custom.base_response import BaseResponse
from xingchen.models.custom.completion.completion_choice import AcAChoice
from xingchen.models.custom.completion.completion_usage import AcAUsage


class AcACompletionResp(BaseResponse):
    """
    Completion response
    """
    id: str = Field(None, description="A unique identifier for the chat completion.")
    created: int = Field(None, description="The Unix timestamp (in seconds) of when the chat completion was created.")
    model: str = Field(None, description="The model used for the chat completion.")
    choices: conlist(AcAChoice) = Field(None, description="A list of chat completion choices. Can be more than one if n is greater than 1.")
    usage: AcAUsage = Field(None, description="Usage statistics for the completion request.")

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=False, exclude_none=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> 'AcACompletionResp':
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=False,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> 'AcACompletionResp':
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.parse_obj(obj)

        _obj = cls.parse_obj({
            'request_id': obj.get('requestId'),
            'error_code': obj.get('errorCode'),
            'error_message': obj.get('errorMessage'),
            'error_name': obj.get('errorName'),
            'http_status_code': obj.get('httpStatusCode'),
            'code': obj.get('code'),
            'error_message_key': obj.get('errorMessageKey'),
            'success': obj.get('success'),
            "id": obj.get("id"),
            "created": obj.get("created"),
            "model": obj.get("model"),
            "choices": [AcAChoice.from_dict(c) for c in obj.get("choices", []) if c is not None],
            "usage": obj.get("usage"),
        })
        return _obj



# flake8: noqa

# import apis into api package
from xingchen.api.character_api_sub import CharacterApiSub
from xingchen.api.chat_api_sub import ChatApiSub
from xingchen.api.chat_message_api_sub import ChatMessageApiSub
from xingchen.api.chat_extract_message_api_sub import ChatExtractMessageApiSub
from xingchen.api.common_api_sub import CommonApiSub
from xingchen.api.groupchat_api_sub import GroupChatApiSub



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from xingchen.models.chat_room_user_dto import ChatRoomUserDTO

class ChatMessageDTO(BaseModel):
    """
    聊天消息  # noqa: E501
    """
    content: Optional[StrictStr] = Field(None, description="消息内容")
    message_type: Optional[StrictStr] = Field(None, alias="messageType", description="消息类型，opening_remarks: 开场白，sys_greetings: 系统问候，user: 用户, character: 角色")
    message_id: Optional[StrictStr] = Field(None, alias="messageId", description="消息ID")
    message_issuer: Optional[ChatRoomUserDTO] = Field(None, alias="messageIssuer")
    session_id: Optional[StrictStr] = Field(None, alias="sessionId", description="消息对话session_id")
    chat_id: Optional[StrictStr] = Field(None, alias="chatId", description="一次对话ID")
    gmt_create: Optional[datetime] = Field(None, alias="gmtCreate", description="消息创建时间")
    is_greeting: Optional[StrictBool] = Field(None, alias="isGreeting", description="是否为开场白")
    rating: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="消息评分")
    regenerate_times: Optional[StrictInt] = Field(None, alias="regenerateTimes", description="重新生成次数")
    __properties = ["content", "messageType", "messageId", "messageIssuer", "sessionId", "chatId", "gmtCreate", "isGreeting", "rating", "regenerateTimes"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChatMessageDTO:
        """Create an instance of ChatMessageDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of message_issuer
        if self.message_issuer:
            _dict['messageIssuer'] = self.message_issuer.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChatMessageDTO:
        """Create an instance of ChatMessageDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatMessageDTO.parse_obj(obj)

        _obj = ChatMessageDTO.parse_obj({
            "content": obj.get("content"),
            "message_type": obj.get("messageType"),
            "message_id": obj.get("messageId"),
            "message_issuer": ChatRoomUserDTO.from_dict(obj.get("messageIssuer")) if obj.get("messageIssuer") is not None else None,
            "session_id": obj.get("sessionId"),
            "chat_id": obj.get("chatId"),
            "gmt_create": obj.get("gmtCreate"),
            "is_greeting": obj.get("isGreeting"),
            "rating": obj.get("rating"),
            "regenerate_times": obj.get("regenerateTimes")
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.input import Input  # noqa: E501

class TestInput(unittest.TestCase):
    """Input unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Input:
        """Test Input
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Input`
        """
        model = Input()  # noqa: E501
        if include_optional:
            return Input(
                prompt = '',
                messages = [
                    xingchen.models.message.Message(
                        name = '', 
                        role = '', 
                        content = '', 
                        finish_reason = '', 
                        meta = xingchen.models.meta.Meta(
                            has_risk = True, 
                            safety_std_answer = '', ), )
                    ],
                aca = xingchen.models.aca.aca()
            )
        else:
            return Input(
        )
        """

    def testInput(self):
        """Test Input"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, conlist

from xingchen.models import Context
from xingchen.models.custom import Usage
from xingchen.models.memory_summary import MemorySummary


class ExtractSummaryDTO(BaseModel):
    memory_results: conlist(MemorySummary) = Field(None, alias="memoryResults")
    usage: Optional[Usage] = Field(None, alias="usage")
    context: Optional[Context] = Field(None, alias="context")
    __properties = ["memoryResults", "usage", "context"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExtractSummaryDTO:
        """Create an instance of ExtractMemoryRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExtractSummaryDTO:
        """Create an instance of ExtractMemoryRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExtractSummaryDTO.parse_obj(obj)

        _obj = ExtractSummaryDTO.parse_obj({
            "memory_results": [MemorySummary.from_dict(_item) for _item in obj.get("memoryResults")] if obj.get(
                "memoryResults") is not None else None,
            "usage": Usage.from_dict(obj.get("usage")) if obj.get("usage") is not None else None,
            "context": Context.from_dict(obj.get("context")) if obj.get("context") is not None else None
        })
        return _obj



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, StrictBool, StrictStr


class AdvancedSettings(BaseModel):
    enable_web_search: Optional[StrictBool] = Field(None, alias="enableWebSearch")
    search_enhanced_keyword: Optional[StrictStr] = Field(None, alias="searchEnhancedKeyword")
    enable_character_kb_search: Optional[StrictBool] = Field(None, alias="enableCharacterKbSearch")
    enable_long_term_memory: Optional[StrictBool] = Field(None, alias="enableLongTermMemory")
    enable_debug: Optional[StrictBool] = Field(None, alias="enableDebug")
    __properties = ["enableWebSearch", "searchEnhancedKeyword", "enableCharacterKbSearch", "enableLongTermMemory", "enableDebug"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AdvancedSettings:
        """Create an instance of AdvancedSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AdvancedSettings:
        """Create an instance of AdvancedSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AdvancedSettings.parse_obj(obj)

        _obj = AdvancedSettings.parse_obj({
            "enable_web_search": obj.get("enableWebSearch"),
            "search_enhanced_keyword": obj.get("searchEnhancedKeyword"),
            "enable_character_kb_search": obj.get("enableCharacterKbSearch"),
            "enable_long_term_memory": obj.get("enableLongTermMemory"),
            "enable_debug": obj.get("enableDebug")
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.character_advanced_config import CharacterAdvancedConfig  # noqa: E501

class TestCharacterAdvancedConfig(unittest.TestCase):
    """CharacterAdvancedConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CharacterAdvancedConfig:
        """Test CharacterAdvancedConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CharacterAdvancedConfig`
        """
        model = CharacterAdvancedConfig()  # noqa: E501
        if include_optional:
            return CharacterAdvancedConfig(
                repository_info = xingchen.models.repository_info.RepositoryInfo(
                    repository_files = [
                        xingchen.models.repository.Repository(
                            file_save_path = '', 
                            filename = '', 
                            file_url = '', 
                            status = '', )
                        ], 
                    status = '', ),
                is_real_info = True,
                search_keyword = '',
                allow_send_image = True,
                image_style = '',
                allow_send_asr = True,
                asr_style = '',
                chat_description = ''
            )
        else:
            return CharacterAdvancedConfig(
        )
        """

    def testCharacterAdvancedConfig(self):
        """Test CharacterAdvancedConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist

class ChatHistoryQueryWhere(BaseModel):
    """
    查询条件  # noqa: E501
    """
    character_id: Optional[StrictStr] = Field(None, alias="characterId", description="角色ID")
    session_id: Optional[StrictStr] = Field(None, alias="sessionId", description="会话ID")
    start_time: Optional[datetime] = Field(None, alias="startTime", description="开始时间")
    end_time: Optional[datetime] = Field(None, alias="endTime", description="结束时间")
    message_ids: Optional[conlist(StrictStr)] = Field(None, alias="messageIds", description="消息ID列表")
    biz_user_id: Optional[StrictStr] = Field(None, alias="bizUserId", description="业务系统对话用户ID")
    __properties = ["characterId", "sessionId", "startTime", "endTime", "messageIds", "bizUserId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChatHistoryQueryWhere:
        """Create an instance of ChatHistoryQueryWhere from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChatHistoryQueryWhere:
        """Create an instance of ChatHistoryQueryWhere from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatHistoryQueryWhere.parse_obj(obj)

        _obj = ChatHistoryQueryWhere.parse_obj({
            "character_id": obj.get("characterId"),
            "session_id": obj.get("sessionId"),
            "start_time": obj.get("startTime"),
            "end_time": obj.get("endTime"),
            "message_ids": obj.get("messageIds"),
            "biz_user_id": obj.get("bizUserId")
        })
        return _obj





# coding: utf-8


from __future__ import annotations

import json
import pprint

from pydantic import BaseModel, Field, StrictStr, StrictBool
from typing import Optional


class PlatformPublishConfig(BaseModel):
    """
    平台发布配置
    """
    enabled: Optional[StrictBool] = Field(..., alias="enabled", description="是否开启")
    private_share_type: StrictStr = Field(..., alias="privateShareType", description="""
     私密分享类型
     * selfShare - 仅自己可与角色聊天 （permConfig.allowChat=0）
     * linkShare - 通过链接分享（允许获得链接的星尘用户可与ta聊天）  （permConfig.allowChat=0）
     * allShare  - 所有星尘用户可见（需要平台审核）  （permConfig.allowChat=1）
    """)
    __properties = ["enabled", "privateShareType"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PlatformPublishConfig:
        """Create an instance of SysReminderRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PlatformPublishConfig:
        """Create an instance of SysReminderRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PlatformPublishConfig.parse_obj(obj)

        _obj = PlatformPublishConfig.parse_obj({
            "enabled": obj.get("enabled"),
            "private_share_type": obj.get("privateShareType")
        })
        return _obj





from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, StrictStr, StrictBool


class PlatformPlugin(BaseModel):
    enabled: Optional[StrictBool] = None
    name: Optional[StrictStr] = Field(None, alias="name")
    __properties = ["enabled", "name"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PlatformPlugin:
        """Create an instance of PlatformPlugin from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PlatformPlugin:
        """Create an instance of PlatformPlugin from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PlatformPlugin.parse_obj(obj)

        _obj = PlatformPlugin.parse_obj({
            "enabled": obj.get("enabled"),
            "name": obj.get("name")
        })
        return _obj



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist

from xingchen.models.advanced_settings import AdvancedSettings
from xingchen.models.character_key import CharacterKey
from xingchen.models.chat_context import ChatContext
from xingchen.models.function_call import Function, FunctionChoice, Plugin
from xingchen.models.memory import Memory
from xingchen.models.message import Message
from xingchen.models.model_parameters import ModelParameters
from xingchen.models.scenario import Scenario
from xingchen.models.user_profile import UserProfile


class ChatReqParams(BaseModel):
    """
    ChatReqParams
    """
    bot_profile: CharacterKey = Field(..., alias="botProfile")
    messages: conlist(Message, max_items=50, min_items=1) = Field(...)
    sample_messages: conlist(Message) = Field(None, alias="sampleMessages")
    advanced_settings: Optional[AdvancedSettings] = Field(None, alias="advancedSettings")
    model_parameters: Optional[ModelParameters] = Field(None, alias="modelParameters")
    user_profile: Optional[UserProfile] = Field(None, alias="userProfile")
    scenario: Optional[Scenario] = None
    streaming: Optional[StrictBool] = None
    source: Optional[StrictStr] = None
    functions: conlist(Function, max_items=50) = Field(None, alias="functionList")
    function_choice: Optional[FunctionChoice] = Field(None, alias="functionChoice")
    plugins: conlist(Plugin, max_items=50) = Field(None, alias="pluginList")
    context: Optional[ChatContext] = Field(None, alias="context")
    memory: Optional[Memory] = Field(None, alias="memory")

    __properties = ["botProfile", "messages", "sampleMessages", "advancedSettings",
                    "modelParameters", "userProfile", "scenario", "streaming", "context", "source", "functionList",
                    "functionChoice", "pluginList", "context", "memory"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChatReqParams:
        """Create an instance of ChatReqParams from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of bot_profile
        if self.bot_profile:
            _dict['botProfile'] = self.bot_profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in messages (list)
        _items = []
        if self.messages:
            for _item in self.messages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['messages'] = _items
        # override the default output from pydantic by calling `to_dict()` of advanced_settings
        if self.advanced_settings:
            _dict['advancedSettings'] = self.advanced_settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of model_parameters
        if self.model_parameters:
            _dict['modelParameters'] = self.model_parameters.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user_profile
        if self.user_profile:
            _dict['userProfile'] = self.user_profile.to_dict()
        # override the default output from pydantic by calling `to_dict()` of scenario
        if self.scenario:
            _dict['scenario'] = self.scenario.to_dict()
        if self.context:
            _dict['context'] = self.context.to_dict()

        _items = []
        if self.functions:
            for _item in self.functions:
                if _item:
                    _items.append(_item)
            _dict['functionList'] = _items

        _items = []
        if self.plugins:
            for _item in self.plugins:
                if _item:
                    _items.append(_item)
            _dict['pluginList'] = _items

        if self.function_choice:
            _dict['functionChoice'] = self.function_choice.to_dict()

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChatReqParams:
        """Create an instance of ChatReqParams from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ChatReqParams.parse_obj(obj)

        _obj = ChatReqParams.parse_obj({
            "bot_profile": CharacterKey.from_dict(obj.get("botProfile")) if obj.get("botProfile") is not None else None,
            "messages": [Message.from_dict(_item) for _item in obj.get("messages")] if obj.get(
                "messages") is not None else None,
            "advanced_settings": AdvancedSettings.from_dict(obj.get("advancedSettings")) if obj.get(
                "advancedSettings") is not None else None,
            "model_parameters": ModelParameters.from_dict(obj.get("modelParameters")) if obj.get(
                "modelParameters") is not None else None,
            "user_profile": UserProfile.from_dict(obj.get("userProfile")) if obj.get(
                "userProfile") is not None else None,
            "scenario": Scenario.from_dict(obj.get("scenario")) if obj.get("scenario") is not None else None,
            "streaming": obj.get("streaming"),
            "source": obj.get("source"),
            "functions": [Function.from_dict(_item) for _item in obj.get("functionList")] if obj.get("functionList") is not None else None,
            "plugins": [Plugin.from_dict(_item) for _item in obj.get("pluginList")] if obj.get("pluginList") is not None else None,
            "function_choice": FunctionChoice.from_dict(obj.get("functionChoice")) if obj.get("functionChoice") is not None else None,
            "context": ChatContext.from_dict(obj.get("context")) if obj.get("context") is not None else None,
            "memory": Memory.from_dict(obj.get("memory")) if obj.get("memory") is not None else None
        })
        return _obj



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.result_dto_page_result_character_dto import ResultDTOPageResultCharacterDTO  # noqa: E501

class TestResultDTOPageResultCharacterDTO(unittest.TestCase):
    """ResultDTOPageResultCharacterDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultDTOPageResultCharacterDTO:
        """Test ResultDTOPageResultCharacterDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultDTOPageResultCharacterDTO`
        """
        model = ResultDTOPageResultCharacterDTO()  # noqa: E501
        if include_optional:
            return ResultDTOPageResultCharacterDTO(
                request_id = '',
                code = 56,
                error_message = '',
                error_message_key = '',
                data = xingchen.models.page_result_character_dto.PageResultCharacterDTO(
                    list = [
                        xingchen.models.character_dto.CharacterDTO(
                            name = '0', 
                            avatar = xingchen.models.file_info_vo.FileInfoVO(
                                file_save_path = '', 
                                filename = '', 
                                file_url = '', ), 
                            introduction = '', 
                            basic_information = '', 
                            opening_line = '', 
                            traits = '', 
                            chat_example = '', 
                            type = '', 
                            chat_objective = '', 
                            advanced_config = xingchen.models.character_advanced_config.CharacterAdvancedConfig(
                                repository_info = xingchen.models.repository_info.RepositoryInfo(
                                    repository_files = [
                                        xingchen.models.repository.Repository(
                                            file_save_path = '', 
                                            filename = '', 
                                            file_url = '', 
                                            status = '', )
                                        ], 
                                    status = '', ), 
                                is_real_info = True, 
                                search_keyword = '', 
                                allow_send_image = True, 
                                image_style = '', 
                                allow_send_asr = True, 
                                asr_style = '', 
                                chat_description = '', ), 
                            character_id = '', 
                            version = 56, 
                            major_version = 56, 
                            gmt_create = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            gmt_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            user_id = '', 
                            modified_by = '', 
                            tags = [
                                ''
                                ], 
                            bubbles = [
                                ''
                                ], 
                            background_img_url = '', 
                            perm_config = xingchen.models.character_permission_config.CharacterPermissionConfig(
                                is_public = 56, 
                                allow_chat = 56, 
                                allow_api = 56, ), 
                            versions = [
                                56
                                ], 
                            manageable = True, 
                            creator = '', 
                            is_pre_configured = True, )
                        ], 
                    page = 56, 
                    page_size = 56, 
                    total = 56, 
                    page_offset_value = 56, ),
                success = True
            )
        else:
            return ResultDTOPageResultCharacterDTO(
        )
        """

    def testResultDTOPageResultCharacterDTO(self):
        """Test ResultDTOPageResultCharacterDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.character_update_dto import CharacterUpdateDTO  # noqa: E501

class TestCharacterUpdateDTO(unittest.TestCase):
    """CharacterUpdateDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CharacterUpdateDTO:
        """Test CharacterUpdateDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CharacterUpdateDTO`
        """
        model = CharacterUpdateDTO()  # noqa: E501
        if include_optional:
            return CharacterUpdateDTO(
                name = '0',
                avatar = xingchen.models.file_info_vo.FileInfoVO(
                    file_save_path = '', 
                    filename = '', 
                    file_url = '', ),
                introduction = '',
                basic_information = '',
                opening_line = '',
                traits = '',
                chat_example = '',
                type = '',
                chat_objective = '',
                advanced_config = xingchen.models.character_advanced_config.CharacterAdvancedConfig(
                    repository_info = xingchen.models.repository_info.RepositoryInfo(
                        repository_files = [
                            xingchen.models.repository.Repository(
                                file_save_path = '', 
                                filename = '', 
                                file_url = '', 
                                status = '', )
                            ], 
                        status = '', ), 
                    is_real_info = True, 
                    search_keyword = '', 
                    allow_send_image = True, 
                    image_style = '', 
                    allow_send_asr = True, 
                    asr_style = '', 
                    chat_description = '', ),
                character_id = '',
                version = 56,
                perm_config = xingchen.models.character_permission_config.CharacterPermissionConfig(
                    is_public = 56, 
                    allow_chat = 56, 
                    allow_api = 56, )
            )
        else:
            return CharacterUpdateDTO(
                name = '0',
                basic_information = '',
                character_id = '',
                version = 56,
        )
        """

    def testCharacterUpdateDTO(self):
        """Test CharacterUpdateDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt

class CharacterPermissionConfig(BaseModel):
    """
    角色权限配置  # noqa: E501
    """
    is_public: StrictInt = Field(..., alias="isPublic", description="是否可查看角色属性(0:不公开;1:公开)")
    allow_chat: StrictInt = Field(..., alias="allowChat", description="允许在平台和其他用户聊天(0:不允许,1:允许)")
    allow_api: StrictInt = Field(..., alias="allowApi", description="允许其他用户通过api调用(0:不允许,1:允许)")
    __properties = ["isPublic", "allowChat", "allowApi"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CharacterPermissionConfig:
        """Create an instance of CharacterPermissionConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CharacterPermissionConfig:
        """Create an instance of CharacterPermissionConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CharacterPermissionConfig.parse_obj(obj)

        _obj = CharacterPermissionConfig.parse_obj({
            "is_public": obj.get("isPublic"),
            "allow_chat": obj.get("allowChat"),
            "allow_api": obj.get("allowApi")
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from xingchen.models.gateway_issued_params import GatewayIssuedParams

class SysReminderRequest(BaseModel):
    """
    系统提醒参数  # noqa: E501
    """
    character_id: StrictStr = Field(..., alias="characterId", description="角色ID")
    content: StrictStr = Field(..., description="系统提醒内容")
    biz_user_id: StrictStr = Field(..., alias="bizUserId", description="业务系统ID")
    __properties = ["characterId", "content", "bizUserId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SysReminderRequest:
        """Create an instance of SysReminderRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SysReminderRequest:
        """Create an instance of SysReminderRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SysReminderRequest.parse_obj(obj)

        _obj = SysReminderRequest.parse_obj({
            "character_id": obj.get("characterId"),
            "content": obj.get("content"),
            "biz_user_id": obj.get("bizUserId")
        })
        return _obj





from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, conlist

from xingchen.models import Message, ModelParameters
from xingchen.models.kv_memory_config import KVMemoryConfig


class ExtractMemoryRequest(BaseModel):
    messages: Optional[conlist(Message, min_items=1)] = Field(...)
    kv_memory_configs: Optional[conlist(KVMemoryConfig)] = Field(None, alias="kvMemoryConfigs")
    model_parameter: Optional[ModelParameters] = Field(None, alias="modelParameter")
    __properties = ["messages", "kvMemoryConfigs", "modelParameter"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExtractMemoryRequest:
        """Create an instance of ExtractMemoryRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExtractMemoryRequest:
        """Create an instance of ExtractMemoryRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExtractMemoryRequest.parse_obj(obj)

        _obj = ExtractMemoryRequest.parse_obj({
            "messages": [Message.from_dict(_item) for _item in obj.get("messages")] if obj.get(
                "messages") is not None else None,
            "kv_memory_configs": [KVMemoryConfig.from_dict(_item) for _item in obj.get("kvMemoryConfigs")] if obj.get(
                "kvMemoryConfigs") is not None else None,
            "model_parameter": ModelParameters.from_dict(obj.get("modelParameter")) if obj.get(
                "modelParameter") is not None else None
        })
        return _obj



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, StrictBool


class ModelParameters(BaseModel):
    """
    ModelParameters
    """
    model_name: Optional[StrictStr] = Field(None, alias="modelName")
    top_p: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="topP")
    top_k: Optional[StrictInt] = Field(None, alias="topK")
    seed: Optional[StrictInt] = None
    max_length: Optional[StrictInt] = Field(None, alias="maxLength")
    min_length: Optional[StrictInt] = Field(None, alias="minLength")
    temperature: Optional[Union[StrictFloat, StrictInt]] = None
    incremental_output: Optional[StrictBool] = Field(False, alias="incrementalOutput")

    __properties = ["modelName", "topP", "topK", "seed", "maxLength", "minLength", "temperature", "incrementalOutput"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ModelParameters:
        """Create an instance of ModelParameters from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ModelParameters:
        """Create an instance of ModelParameters from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ModelParameters.parse_obj(obj)

        _obj = ModelParameters.parse_obj({
            "model_name": obj.get("modelName"),
            "top_p": obj.get("topP"),
            "top_k": obj.get("topK"),
            "seed": obj.get("seed"),
            "max_length": obj.get("maxLength"),
            "min_length": obj.get("minLength"),
            "temperature": obj.get("temperature"),
            "incremental_output": obj.get("incrementalOutput")
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from xingchen.api.character_api_sub import CharacterApiSub  # noqa: E501


class TestCharacterApiSub(unittest.TestCase):
    """CharacterApiSub unit test stubs"""

    def setUp(self) -> None:
        self.api = CharacterApiSub()  # noqa: E501

    def tearDown(self) -> None:
        pass

    def test_character_details(self) -> None:
        """Test case for character_details

        角色详情  # noqa: E501
        """
        pass

    def test_character_details1(self) -> None:
        """Test case for character_details1

        角色详情  # noqa: E501
        """
        pass

    def test_create(self) -> None:
        """Test case for create

        创建角色  # noqa: E501
        """
        pass

    def test_create1(self) -> None:
        """Test case for create1

        创建角色  # noqa: E501
        """
        pass

    def test_create_or_update_version(self) -> None:
        """Test case for create_or_update_version

        创建或更新角色版本  # noqa: E501
        """
        pass

    def test_create_or_update_version1(self) -> None:
        """Test case for create_or_update_version1

        创建或更新角色版本  # noqa: E501
        """
        pass

    def test_delete(self) -> None:
        """Test case for delete

        删除角色  # noqa: E501
        """
        pass

    def test_delete1(self) -> None:
        """Test case for delete1

        删除角色  # noqa: E501
        """
        pass

    def test_list_character_versions(self) -> None:
        """Test case for list_character_versions

        角色版本列表  # noqa: E501
        """
        pass

    def test_list_character_versions1(self) -> None:
        """Test case for list_character_versions1

        角色版本列表  # noqa: E501
        """
        pass

    def test_recommend_character_version(self) -> None:
        """Test case for recommend_character_version

        角色版本列表  # noqa: E501
        """
        pass

    def test_recommend_character_version1(self) -> None:
        """Test case for recommend_character_version1

        角色版本列表  # noqa: E501
        """
        pass

    def test_search(self) -> None:
        """Test case for search

        查询角色  # noqa: E501
        """
        pass

    def test_search1(self) -> None:
        """Test case for search1

        查询角色  # noqa: E501
        """
        pass

    def test_update(self) -> None:
        """Test case for update

        更新角色信息  # noqa: E501
        """
        pass

    def test_update1(self) -> None:
        """Test case for update1

        更新角色信息  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.result_dto_character_dto import ResultDTOCharacterDTO  # noqa: E501

class TestResultDTOCharacterDTO(unittest.TestCase):
    """ResultDTOCharacterDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultDTOCharacterDTO:
        """Test ResultDTOCharacterDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultDTOCharacterDTO`
        """
        model = ResultDTOCharacterDTO()  # noqa: E501
        if include_optional:
            return ResultDTOCharacterDTO(
                request_id = '',
                code = 56,
                error_message = '',
                error_message_key = '',
                data = xingchen.models.character_dto.CharacterDTO(
                    name = '0', 
                    avatar = xingchen.models.file_info_vo.FileInfoVO(
                        file_save_path = '', 
                        filename = '', 
                        file_url = '', ), 
                    introduction = '', 
                    basic_information = '', 
                    opening_line = '', 
                    traits = '', 
                    chat_example = '', 
                    type = '', 
                    chat_objective = '', 
                    advanced_config = xingchen.models.character_advanced_config.CharacterAdvancedConfig(
                        repository_info = xingchen.models.repository_info.RepositoryInfo(
                            repository_files = [
                                xingchen.models.repository.Repository(
                                    file_save_path = '', 
                                    filename = '', 
                                    file_url = '', 
                                    status = '', )
                                ], 
                            status = '', ), 
                        is_real_info = True, 
                        search_keyword = '', 
                        allow_send_image = True, 
                        image_style = '', 
                        allow_send_asr = True, 
                        asr_style = '', 
                        chat_description = '', ), 
                    character_id = '', 
                    version = 56, 
                    major_version = 56, 
                    gmt_create = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    gmt_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    user_id = '', 
                    modified_by = '', 
                    tags = [
                        ''
                        ], 
                    bubbles = [
                        ''
                        ], 
                    background_img_url = '', 
                    perm_config = xingchen.models.character_permission_config.CharacterPermissionConfig(
                        is_public = 56, 
                        allow_chat = 56, 
                        allow_api = 56, ), 
                    versions = [
                        56
                        ], 
                    manageable = True, 
                    creator = '', 
                    is_pre_configured = True, ),
                success = True
            )
        else:
            return ResultDTOCharacterDTO(
        )
        """

    def testResultDTOCharacterDTO(self):
        """Test ResultDTOCharacterDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.chat_req_params import ChatReqParams  # noqa: E501

class TestChatReqParams(unittest.TestCase):
    """ChatReqParams unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatReqParams:
        """Test ChatReqParams
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatReqParams`
        """
        model = ChatReqParams()  # noqa: E501
        if include_optional:
            return ChatReqParams(
                bot_profile = xingchen.models.character_key.CharacterKey(
                    character_id = '', 
                    version = 56, ),
                messages = [
                    xingchen.models.message.Message(
                        name = '', 
                        role = '', 
                        content = '', 
                        finish_reason = '', 
                        meta = xingchen.models.meta.Meta(
                            has_risk = True, 
                            safety_std_answer = '', ), )
                    ],
                advanced_settings = xingchen.models.advanced_settings.AdvancedSettings(
                    enable_web_search = True, 
                    search_enhanced_keyword = '', 
                    enable_character_kb_search = True, 
                    enable_long_term_memory = True, 
                    enable_debug = True, ),
                model_parameters = xingchen.models.model_parameters.ModelParameters(
                    model_name = '', 
                    top_p = 1.337, 
                    top_k = 56, 
                    seed = 56, 
                    max_length = 56, 
                    temperature = 1.337, ),
                user_profile = xingchen.models.user_profile.UserProfile(
                    user_id = '', 
                    user_name = '', 
                    basic_info = '', ),
                scenario = xingchen.models.scenario.Scenario(
                    description = '', ),
                streaming = True,
                context = xingchen.models.context.Context(
                    chat_room_id = 56, 
                    session_id = '', 
                    chat_id = '', 
                    message_id = '', 
                    reply_message_id = '', 
                    enable_data_inspection = True, 
                    is_save = True, 
                    request_id = '', 
                    model_request_id = '', 
                    character_pk = 56, 
                    model_name = '', ),
                source = ''
            )
        else:
            return ChatReqParams(
                bot_profile = xingchen.models.character_key.CharacterKey(
                    character_id = '', 
                    version = 56, ),
                messages = [
                    xingchen.models.message.Message(
                        name = '', 
                        role = '', 
                        content = '', 
                        finish_reason = '', 
                        meta = xingchen.models.meta.Meta(
                            has_risk = True, 
                            safety_std_answer = '', ), )
                    ],
        )
        """

    def testChatReqParams(self):
        """Test ChatReqParams"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8


from typing import Union, Generator

import requests
from pydantic import Field
from pydantic import validate_arguments
from sseclient import SSEClient
from typing_extensions import Annotated

from xingchen.aca_util import handle_sse_response
from xingchen.api_client import ApiClient
from xingchen.exceptions import (
    ApiTypeError
)
from xingchen.models.base_chat_request import BaseChatRequest
from xingchen.models.custom import ChatResponse


class GroupChatApiSub:
    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    def version(self):
        return self.api_client.api_version()

    @validate_arguments
    def chat(self, chat_req_params: Annotated[BaseChatRequest, Field(..., description="对话请求")],
             **kwargs) -> Union[ChatResponse, Generator[ChatResponse, None, None]]:
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the chat_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.chat_with_http_info(chat_req_params, **kwargs)  # noqa: E501

    @validate_arguments
    def chat_with_http_info(self, base_chat_request: Annotated[BaseChatRequest, Field(..., description="对话请求")],
                            **kwargs) -> Union[ChatResponse, Generator[ChatResponse, None, None]]:  # noqa: E501

        _params = locals()

        _all_params = [
            'base_chat_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method chat" % _key
                )
            _params[_key] = _val

        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['base_chat_request'] is not None:
            _body_params = _params['base_chat_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/event-stream'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "object",
        }

        # 参数转化
        version = self.version()

        is_stream = 'enable' == _header_params.get('X-DashScope-SSE') or 'enable' == _header_params.get('X-AcA-SSE')
        path = '/{0}/api/groupchat/send'.format(version)
        host = self.api_client.configuration.host

        _header_params['x-fag-appcode'] = 'aca'
        _header_params['x-fag-servicename'] = 'aca-groupchat-send'
        _header_params['Authorization'] = 'Bearer ' + self.api_client.configuration.access_token

        if is_stream:
            _header_params['x-fag-servicename'] = 'aca-groupchat-send-sse'
            _header_params['Accept'] = 'text/event-stream;charset=UTF-8'
            body_params = self.api_client.sanitize_for_serialization(_body_params)

            request = requests.post(
                host + path,
                headers=_header_params,
                json=body_params,
                stream=True
            )
            client = SSEClient(request)
            return (res for res in handle_sse_response(client))

        response = self.api_client.call_api(
            '/{0}/api/groupchat/send'.format(version), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

        return ChatResponse.from_dict(response)



# coding: utf-8


from __future__ import annotations

import json
import pprint
from typing import Optional, Any

from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist, StrictInt

from xingchen.models.long_term_memory import LongTermMemory
from xingchen.models.repository_info import RepositoryInfo
from xingchen.models.custom.character_model_parameters import CharacterModelParameters


class CharacterAdvancedConfig(BaseModel):
    """
    角色高级配置
    """
    repository_info: Optional[RepositoryInfo] = Field(None, alias="repositoryInfo")
    is_real_info: Optional[StrictBool] = Field(None, alias="isRealInfo", description="是否返回真实世界信息")
    search_keyword: Optional[StrictStr] = Field(None, alias="searchKeyword", description="web搜索必填关键字")
    allow_send_image: Optional[StrictBool] = Field(None, alias="allowSendImage", description="是否允许角色发送图片")
    image_style: Optional[StrictStr] = Field(None, alias="imageStyle", description="角色发送图片的风格")
    allow_send_asr: Optional[StrictBool] = Field(None, alias="allowSendAsr", description="是否允许角色发送语音")
    asr_style: Optional[StrictStr] = Field(None, alias="asrStyle", description="角色发送语音风格")
    chat_description: Optional[StrictStr] = Field(None, alias="chatDescription", description="对话介绍")
    is_real_time: Optional[StrictBool] = Field(None, alias="isRealTime", description="是否获取真实时间")
    short_term_memory_round: Optional[StrictInt] = Field(None, alias="shortTermMemoryRound", description="""
    短期记忆轮数，若使用平台对话历史，可以通过该参数获取指定轮数的对话历史作为短期记忆，超过该轮数，会到长期记忆库中搜索用户query相关问题答案
    """)
    long_term_memories: Optional[conlist(LongTermMemory)] = Field(None, alias="longTermMemories",
                                                                  description="打开长期记忆设置")
    platform_plugins: Optional[conlist(Any)] = Field(None, alias="platformPlugins", description="平台插件")

    __properties = ["repositoryInfo", "isRealInfo", "searchKeyword", "allowSendImage", "imageStyle", "allowSendAsr",
                    "asrStyle", "chatDescription", "shortTermMemoryRound", "longTermMemories", "platformPlugins"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CharacterAdvancedConfig:
        """Create an instance of CharacterAdvancedConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of repository_info
        if self.repository_info:
            _dict['repositoryInfo'] = self.repository_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CharacterAdvancedConfig:
        """Create an instance of CharacterAdvancedConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CharacterAdvancedConfig.parse_obj(obj)

        _obj = CharacterAdvancedConfig.parse_obj({
            "repository_info": RepositoryInfo.from_dict(obj.get("repositoryInfo")) if obj.get(
                "repositoryInfo") is not None else None,
            "is_real_info": obj.get("isRealInfo"),
            "search_keyword": obj.get("searchKeyword"),
            "allow_send_image": obj.get("allowSendImage"),
            "image_style": obj.get("imageStyle"),
            "allow_send_asr": obj.get("allowSendAsr"),
            "asr_style": obj.get("asrStyle"),
            "chat_description": obj.get("chatDescription"),
            "is_real_time": obj.get("isRealTime"),
            "short_term_memory_round": obj.get("shortTermMemoryRound"),
            "long_term_memories": [LongTermMemory.from_dict(_item) for _item in obj.get("longTermMemories")] if obj.get(
                "longTermMemories") is not None else None,
            "platform_plugins": obj.get("platformPlugins")
        })
        return _obj



# coding: utf-8

import json
from typing import Optional

from pydantic import BaseModel, Field, StrictStr


class GroupChatRoomInfo(BaseModel):
    """
    群聊室信息
    """
    name: StrictStr = Field(..., alias="name", description="群聊室名称")
    description: Optional[StrictStr] = Field(None, alias="description", description="群聊室描述")

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        return json.dumps(self.dict(by_alias=True, exlude_none=True), indent=4)

    def to_json(self) -> str:
        return json.dumps(self.dict(by_alias=True, exclude_none=True))

    def to_dict(self):
        return self.dict(by_alias=True, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> 'GroupChatRoomInfo':
        try:
            obj_dict = json.loads(json_str)
            return cls.from_json(obj_dict)
        except json.JSONDecodeError:
            raise ValueError("The input string is not a valid JSON string")

    @classmethod
    def from_dict(cls, obj: dict) -> 'GroupChatRoomInfo':
        if not isinstance(obj, dict):
            raise TypeError("The input object is not a dict")
        return cls(name=obj.get("name"), description=obj.get("description"))



from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic import BaseModel, Field, StrictStr


class AcAReqMessage(BaseModel):
    """
    Message
    """
    name: Optional[StrictStr] = Field(None, description="角色名称")
    role: StrictStr = Field(...,
                            description="角色类型, user-用户发送的内容；system-系统指令；assistant-助手消息；tool-工具类消息")
    content: Optional[StrictStr] = Field(None, description="消息内容")
    tool_call_id: Optional[StrictStr] = Field(None, description="模型生成的工具调用id")

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AcAReqMessage:
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)

    @classmethod
    def from_dict(cls, obj: dict) -> AcAReqMessage:
        """Create an instance of Message from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.parse_obj(obj)

        _obj = cls.parse_obj({
            "name": obj.get("name"),
            "role": obj.get("role"),
            "content": obj.get("content"),
            "tool_call_id": obj.get("tool_call_id")
        })
        return _obj



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import re  # noqa: F401
import io
import warnings
from typing import List, Optional

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from pydantic import Field, StrictInt, StrictStr

from xingchen.models.character_create_dto import CharacterCreateDTO
from xingchen.models.character_desc_generated_request import CharacterDescGeneratedRequest
from xingchen.models.character_query_dto import CharacterQueryDTO
from xingchen.models.character_update_dto import CharacterUpdateDTO
from xingchen.models.character_version_create_or_update_dto import CharacterVersionCreateOrUpdateDTO
from xingchen.models.platform_plugin import PlatformPlugin
from xingchen.models.reject_answer_plugin import RejectAnswerPlugin
from xingchen.models.result_dto_boolean import ResultDTOBoolean
from xingchen.models.result_dto_character_desc_dto import ResultDTOCharacterDescDTO
from xingchen.models.result_dto_character_dto import ResultDTOCharacterDTO
from xingchen.models.result_dto_character_key import ResultDTOCharacterKey
from xingchen.models.result_dto_list_character_dto import ResultDTOListCharacterDTO
from xingchen.models.result_dto_page_result_character_dto import ResultDTOPageResultCharacterDTO

from xingchen.api_client import ApiClient
from xingchen.api_response import ApiResponse
from xingchen.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)
from xingchen.models.text_to_image_plugin import TextToImagePlugin


class CharacterApiSub:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def character_details(self, character_id: Annotated[StrictStr, Field(..., description="角色ID")],
                          **kwargs) -> ResultDTOCharacterDTO:  # noqa: E501
        """角色详情  # noqa: E501

        获取角色详细信息  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.character_details(character_id, 1, async_req=True)
        >>> result = thread.get()

        :param character_id: 角色ID (required)
        :type character_id: str
        :param version: 角色版本 (required)
        :type version: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOCharacterDTO
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the character_details_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.character_details_with_http_info(character_id, 1, **kwargs)  # noqa: E501

    @validate_arguments
    def character_details_with_http_info(self, character_id: Annotated[StrictStr, Field(..., description="角色ID")],
                                         version: Annotated[StrictInt, Field(..., description="角色版本")],
                                         **kwargs) -> ApiResponse:  # noqa: E501
        """角色详情  # noqa: E501

        获取角色详细信息  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.character_details_with_http_info(character_id, version, async_req=True)
        >>> result = thread.get()

        :param character_id: 角色ID (required)
        :type character_id: str
        :param version: 角色版本 (required)
        :type version: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOCharacterDTO, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'character_id',
            'version'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method character_details" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('character_id') is not None:  # noqa: E501
            _query_params.append(('characterId', _params['character_id']))

        if _params.get('version') is not None:  # noqa: E501
            _query_params.append(('version', _params['version']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOCharacterDTO",
        }

        return self.api_client.call_api(
            '/{api_version}/api/character/details'.format(api_version=self.api_client.configuration.api_version), 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create(self, character_create_dto: CharacterCreateDTO, **kwargs) -> ResultDTOCharacterKey:  # noqa: E501
        """创建角色  # noqa: E501

        基于角色名称、人设和对话示例定义角色，并返回角色ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(character_create_dto, async_req=True)
        >>> result = thread.get()

        :param character_create_dto: (required)
        :type character_create_dto: CharacterCreateDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOCharacterKey
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_with_http_info(character_create_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def create_with_http_info(self, character_create_dto: CharacterCreateDTO, **kwargs) -> ApiResponse:  # noqa: E501
        """创建角色  # noqa: E501

        基于角色名称、人设和对话示例定义角色，并返回角色ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(character_create_dto, async_req=True)
        >>> result = thread.get()

        :param character_create_dto: (required)
        :type character_create_dto: CharacterCreateDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOCharacterKey, status_code(int), headers(HTTPHeaderDict))
        """
        if character_create_dto.advanced_config is not None:
            self.pre_check_plugin_process(character_create_dto.advanced_config.platform_plugins)
        _params = locals()

        _all_params = [
            'character_create_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['character_create_dto'] is not None:
            _body_params = _params['character_create_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOCharacterKey",
        }

        return self.api_client.call_api(
            '/{0}/api/character/create'.format(self.api_client.api_version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_or_update_version(self, character_version_create_or_update_dto: Annotated[
        CharacterVersionCreateOrUpdateDTO, Field(..., description="待更新的角色信息")],
                                 **kwargs) -> ApiResponse:  # noqa: E501
        """创建或更新角色版本  # noqa: E501

        必须字段：characterId 和 version。返回角色版本详情。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_or_update_version(character_version_create_or_update_dto, async_req=True)
        >>> result = thread.get()

        :param character_version_create_or_update_dto: 待更新的角色信息 (required)
        :type character_version_create_or_update_dto: CharacterVersionCreateOrUpdateDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOCharacterDTO
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_or_update_version_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_or_update_version_with_http_info(character_version_create_or_update_dto,
                                                            **kwargs)  # noqa: E501

    @validate_arguments
    def create_or_update_version_with_http_info(self, character_version_create_or_update_dto: Annotated[
        CharacterVersionCreateOrUpdateDTO, Field(..., description="待更新的角色信息")],
                                                **kwargs) -> ApiResponse:  # noqa: E501
        """创建或更新角色版本  # noqa: E501

        必须字段：characterId 和 version。返回角色版本详情。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_or_update_version_with_http_info(character_version_create_or_update_dto, async_req=True)
        >>> result = thread.get()

        :param character_version_create_or_update_dto: 待更新的角色信息 (required)
        :type character_version_create_or_update_dto: CharacterVersionCreateOrUpdateDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOCharacterDTO, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'character_version_create_or_update_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_or_update_version" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['character_version_create_or_update_dto'] is not None:
            _body_params = _params['character_version_create_or_update_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOCharacterDTO",
        }

        return self.api_client.call_api(
            '/{0}/api/character/createOrUpdateVersion'.format(self.api_client.api_version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete(self, character_id: Annotated[StrictStr, Field(..., description="待删除的 characterId")],
               **kwargs) -> ResultDTOBoolean:  # noqa: E501
        """删除角色  # noqa: E501

        （逻辑）删除 character。返回成功或失败。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete(character_id, 1, async_req=True)
        >>> result = thread.get()

        :param character_id: 待删除的 characterId (required)
        :type character_id: str
        :param version: 待删除的版本 (required)
        :type version: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOBoolean
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the delete_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.delete_with_http_info(character_id, 1, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_with_http_info(self, character_id: Annotated[StrictStr, Field(..., description="待删除的 characterId")],
                              version: Annotated[StrictInt, Field(..., description="待删除的版本")],
                              **kwargs) -> ApiResponse:  # noqa: E501
        """删除角色  # noqa: E501

        （逻辑）删除 character。返回成功或失败。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_with_http_info(character_id, version, async_req=True)
        >>> result = thread.get()

        :param character_id: 待删除的 characterId (required)
        :type character_id: str
        :param version: 待删除的版本 (required)
        :type version: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOBoolean, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'character_id',
            'version'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('character_id') is not None:  # noqa: E501
            _query_params.append(('characterId', _params['character_id']))

        if _params.get('version') is not None:  # noqa: E501
            _query_params.append(('version', _params['version']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = {
            'characterId': _params.get('character_id'),
            'version': _params.get('version')
        }

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501
        _header_params['Content-Type'] = self.api_client.select_header_content_type(['application/json'])

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/character/delete'.format(self.api_client.api_version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_character_versions(self, character_id: Annotated[StrictStr, Field(..., description="角色 characterId")],
                                **kwargs) -> ResultDTOListCharacterDTO:  # noqa: E501
        """角色版本列表  # noqa: E501

        获取角色版本列表  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_character_versions(character_id, async_req=True)
        >>> result = thread.get()

        :param character_id: 角色 characterId (required)
        :type character_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOListCharacterDTO
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the list_character_versions_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.list_character_versions_with_http_info(character_id, **kwargs)  # noqa: E501

    @validate_arguments
    def list_character_versions_with_http_info(self, character_id: Annotated[
        StrictStr, Field(..., description="角色 characterId")], **kwargs) -> ApiResponse:  # noqa: E501
        """角色版本列表  # noqa: E501

        获取角色版本列表  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_character_versions_with_http_info(character_id, async_req=True)
        >>> result = thread.get()

        :param character_id: 角色 characterId (required)
        :type character_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOListCharacterDTO, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'character_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_character_versions" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['character_id']:
            _path_params['characterId'] = _params['character_id']

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOListCharacterDTO",
        }

        version = self.api_client.api_version()
        if not version or version.__eq__('v2'):
            _header_params['x-fag-servicename'] = 'aca-character-versions'

        return self.api_client.call_api(
            '/' + version + '/api/character/versions/{characterId}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def recommend_character_version(self,
                                    character_id: Annotated[StrictStr, Field(..., description="角色 characterId")],
                                    **kwargs) -> ResultDTOCharacterDTO:  # noqa: E501
        """角色版本列表  # noqa: E501

        获取角色版本列表  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recommend_character_version(character_id, async_req=True)
        >>> result = thread.get()

        :param character_id: 角色 characterId (required)
        :type character_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOCharacterDTO
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the recommend_character_version_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.recommend_character_version_with_http_info(character_id, **kwargs)  # noqa: E501

    @validate_arguments
    def recommend_character_version_with_http_info(self, character_id: Annotated[
        StrictStr, Field(..., description="角色 characterId")], **kwargs) -> ApiResponse:  # noqa: E501
        """角色版本列表  # noqa: E501

        获取角色版本列表  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recommend_character_version_with_http_info(character_id, async_req=True)
        >>> result = thread.get()

        :param character_id: 角色 characterId (required)
        :type character_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOCharacterDTO, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'character_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recommend_character_version" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['character_id']:
            _path_params['characterId'] = _params['character_id']

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOCharacterDTO",
        }

        version = self.api_client.api_version()
        if not version or version.__eq__('v2'):
            _header_params['x-fag-servicename'] = 'aca-character-version-recommend'

        return self.api_client.call_api(
            '/' + self.api_client.api_version() + '/api/character/newversion/recommend/{characterId}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def search(self, character_query_dto: Annotated[CharacterQueryDTO, Field(..., description="查询条件")],
               **kwargs) -> ResultDTOPageResultCharacterDTO:  # noqa: E501
        """查询角色  # noqa: E501

        查询角色： - 可以指定的查询字段，and 关系：    - 角色名称：左匹配    - 查询范围      - my - 只查询我创建的角色      - public - 查询平台开放的角色      - pre_configured - 预制角色 - 可以指定一定的排序规则，如更新时间倒排。 - 搜索结果为 角色详情。 - 支持分页。   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search(character_query_dto, async_req=True)
        >>> result = thread.get()

        :param character_query_dto: 查询条件 (required)
        :type character_query_dto: CharacterQueryDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOPageResultCharacterDTO
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the search_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.search_with_http_info(character_query_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def search_with_http_info(self,
                              character_query_dto: Annotated[CharacterQueryDTO, Field(..., description="查询条件")],
                              **kwargs) -> ApiResponse:  # noqa: E501
        """查询角色  # noqa: E501

        查询角色： - 可以指定的查询字段，and 关系：    - 角色名称：左匹配    - 查询范围      - my - 只查询我创建的角色      - public - 查询平台开放的角色      - pre_configured - 预制角色 - 可以指定一定的排序规则，如更新时间倒排。 - 搜索结果为 角色详情。 - 支持分页。   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search_with_http_info(character_query_dto, async_req=True)
        >>> result = thread.get()

        :param character_query_dto: 查询条件 (required)
        :type character_query_dto: CharacterQueryDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOPageResultCharacterDTO, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'character_query_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['character_query_dto'] is not None:
            _body_params = _params['character_query_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOPageResultCharacterDTO",
        }

        return self.api_client.call_api(
            '/{0}/api/character/search'.format(self.api_client.api_version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update(self, character_update_dto: Annotated[CharacterUpdateDTO, Field(..., description="待更新的角色信息")],
               **kwargs) -> ResultDTOBoolean:  # noqa: E501
        """更新角色信息  # noqa: E501

        必须字段：characterId。返回成功或失败。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(character_update_dto, async_req=True)
        >>> result = thread.get()

        :param character_update_dto: 待更新的角色信息 (required)
        :type character_update_dto: CharacterUpdateDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultDTOBoolean
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the update_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.update_with_http_info(character_update_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def update_with_http_info(self, character_update_dto: Annotated[
        CharacterUpdateDTO, Field(..., description="待更新的角色信息")], **kwargs) -> ApiResponse:  # noqa: E501
        """更新角色信息  # noqa: E501

        必须字段：characterId。返回成功或失败。  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(character_update_dto, async_req=True)
        >>> result = thread.get()

        :param character_update_dto: 待更新的角色信息 (required)
        :type character_update_dto: CharacterUpdateDTO
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultDTOBoolean, status_code(int), headers(HTTPHeaderDict))
        """
        if character_update_dto.advanced_config is not None:
            self.pre_check_plugin_process(platform_plugins=character_update_dto.advanced_config.platform_plugins)

        _params = locals()

        _all_params = [
            'character_update_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['character_update_dto'] is not None:
            _body_params = _params['character_update_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/character/update'.format(self.api_client.api_version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @staticmethod
    def pre_check_plugin_process(platform_plugins: List[PlatformPlugin]):
        if platform_plugins is None or len(platform_plugins) == 0:
            return
        for platform_plugin in platform_plugins:
            if isinstance(platform_plugin, TextToImagePlugin):
                platform_plugin.enabled = False if platform_plugin.enabled is None else platform_plugin.enabled
                if not platform_plugin.name:
                    platform_plugin.name = "text_to_image_plugin"
                continue
            if isinstance(platform_plugin, RejectAnswerPlugin):
                platform_plugin.enabled = False if platform_plugin.enabled is None else platform_plugin.enabled
                if not platform_plugin.name:
                    platform_plugin.name = "reject_answer_plugin"
                continue
            raise TypeError("Wrong plugin class type")

    @validate_arguments
    def auto_generate_desc(self, character_desc_generate_request: CharacterDescGeneratedRequest,
                           **kwargs) -> ResultDTOCharacterDescDTO:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.auto_generate_desc_with_http_info(character_desc_generate_request, **kwargs)  # noqa: E501

    @validate_arguments
    def auto_generate_desc_with_http_info(self, character_desc_generate_request: CharacterDescGeneratedRequest,
                                          **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'character_desc_generate_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auto_generate_desc" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['character_desc_generate_request'] is not None:
            _body_params = _params['character_desc_generate_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOCharacterDescDTO",
        }

        return self.api_client.call_api(
            '/{0}/api/character/auto/desc'.format(self.api_client.api_version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

from __future__ import annotations

import json
import pprint

from pydantic import BaseModel, Field, StrictStr, StrictInt, StrictBool, conlist
from typing import Optional


class BaseResponse(BaseModel):
    request_id: Optional[StrictStr] = Field(None, alias="requestId")
    error_code: Optional[StrictInt] = Field(None, alias="errorCode")
    error_message: Optional[StrictStr] = Field(None, alias="errorMessage")
    error_name: Optional[StrictStr] = Field(None, alias="errorName")
    http_status_code: Optional[StrictInt] = Field(None, alias="httpStatusCode")

    success: Optional[StrictBool] = Field(None, alias="success")
    code: Optional[StrictInt] = Field(None, alias="code")
    message: Optional[StrictBool] = Field(None, alias="message")
    error_message_key: Optional[StrictStr] = Field(None, alias="errorMessageKey")

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        return json.dumps(self.to_dict())

    def to_dict(self):
        return self.dict(by_alias=True, exclude={}, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> BaseResponse:
        return cls.from_dict(json.loads(json_str))

    @classmethod
    def from_dict(cls, obj: dict) -> BaseResponse | None:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BaseResponse.parse_obj(obj)

        return BaseResponse.parse_obj({
            'request_id': obj.get('requestId'),
            'error_code': obj.get('errorCode'),
            'error_message': obj.get('errorMessage'),
            'error_name': obj.get('errorName'),
            'http_status_code': obj.get('httpStatusCode'),
            'code': obj.get('code'),
            'error_message_key': obj.get('errorMessageKey'),
            'success': obj.get('success')
        })



from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, StrictStr

from xingchen.models.model_parameters import ModelParameters


class CharacterDescGeneratedRequest(BaseModel):
    type: Optional[StrictStr] = Field(None, alias="type")
    file_url: Optional[StrictStr] = Field(None, alias="fileUrl")
    text: Optional[StrictStr] = Field(None, alias="text")
    file_name: Optional[StrictStr] = Field(None, alias="fileName")
    model_parameter: Optional[ModelParameters] = Field(None, alias="modelParameter")
    __properties = ["type", "fileUrl", "text", "fileName", "modelParameter"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CharacterDescGeneratedRequest:
        """Create an instance of CharacterDescGeneratedRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CharacterDescGeneratedRequest:
        """Create an instance of CharacterDescGeneratedRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CharacterDescGeneratedRequest.parse_obj(obj)

        _obj = CharacterDescGeneratedRequest.parse_obj({
            "type": obj.get("type"),
            "file_url": obj.get("fileUrl"),
            "text": obj.get("text"),
            "file_name": obj.get("fileName"),
            "model_parameter": ModelParameters.from_dict(obj.get("modelParameter")) if obj.get(
                "modelParameter") is not None else None
        })
        return _obj



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.context import Context  # noqa: E501

class TestContext(unittest.TestCase):
    """Context unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Context:
        """Test Context
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Context`
        """
        model = Context()  # noqa: E501
        if include_optional:
            return Context(
                chat_room_id = 56,
                session_id = '',
                chat_id = '',
                message_id = '',
                reply_message_id = '',
                enable_data_inspection = True,
                is_save = True,
                request_id = '',
                model_request_id = '',
                character_pk = 56,
                model_name = ''
            )
        else:
            return Context(
        )
        """

    def testContext(self):
        """Test Context"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, StrictInt, StrictStr, constr, conlist

from xingchen.models.character_advanced_config import CharacterAdvancedConfig
from xingchen.models.file_info_vo import FileInfoVO


class CharacterVersionCreateOrUpdateDTO(BaseModel):
    """
    角色版本创建或更新对象  # noqa: E501
    """
    name: constr(strict=True, max_length=20, min_length=1) = Field(..., description="角色名称(最多20个字符)")
    avatar: Optional[FileInfoVO] = None
    introduction: Optional[StrictStr] = Field(None, description="角色描述")
    basic_information: StrictStr = Field(..., alias="basicInformation", description="基本信息")
    opening_line: Optional[StrictStr] = Field(None, alias="openingLine", description="开场白")
    traits: Optional[StrictStr] = Field(None, description="角色特点")
    chat_example: Optional[StrictStr] = Field(None, alias="chatExample", description="聊天示例")
    type: Optional[StrictStr] = Field(None, description="角色类型，virtual:虚拟角色，reproduction:已知角色复刻")
    chat_objective: Optional[StrictStr] = Field(None, alias="chatObjective", description="对话目标")
    advanced_config: Optional[CharacterAdvancedConfig] = Field(None, alias="advancedConfig")
    character_id: StrictStr = Field(..., alias="characterId", description="角色标识")
    version: Optional[StrictInt] = Field(None, description="角色版本，相同角色版本号唯一")
    role_types: Optional[conlist(StrictStr)] = Field(None, alias="roleTypes", description="角色类型")
    __properties = ["name", "avatar", "introduction", "basicInformation", "openingLine", "traits", "chatExample",
                    "type", "chatObjective", "advancedConfig", "characterId", "version", "roleTypes"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CharacterVersionCreateOrUpdateDTO:
        """Create an instance of CharacterVersionCreateOrUpdateDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of avatar
        if self.avatar:
            _dict['avatar'] = self.avatar.to_dict()
        # override the default output from pydantic by calling `to_dict()` of advanced_config
        if self.advanced_config:
            _dict['advancedConfig'] = self.advanced_config.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CharacterVersionCreateOrUpdateDTO:
        """Create an instance of CharacterVersionCreateOrUpdateDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CharacterVersionCreateOrUpdateDTO.parse_obj(obj)

        _obj = CharacterVersionCreateOrUpdateDTO.parse_obj({
            "name": obj.get("name"),
            "avatar": FileInfoVO.from_dict(obj.get("avatar")) if obj.get("avatar") is not None else None,
            "introduction": obj.get("introduction"),
            "basic_information": obj.get("basicInformation"),
            "opening_line": obj.get("openingLine"),
            "traits": obj.get("traits"),
            "chat_example": obj.get("chatExample"),
            "type": obj.get("type"),
            "chat_objective": obj.get("chatObjective"),
            "advanced_config": CharacterAdvancedConfig.from_dict(obj.get("advancedConfig")) if obj.get(
                "advancedConfig") is not None else None,
            "character_id": obj.get("characterId"),
            "version": obj.get("version"),
            "role_types": obj.get("roleTypes"),
        })
        return _obj



# coding: utf-8
from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic import BaseModel, Field, StrictStr, StrictInt

from xingchen.models.custom.completion.completion_resp_message import AcARespMessage


class AcAChoice(BaseModel):
    index: Optional[StrictInt] = Field(None, alias="index")
    finish_reason: Optional[StrictStr] = Field(None, alias="finish_reason")
    message: Optional[AcARespMessage] = Field(None, alias="message")

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        return json.dumps(self.to_dict())

    def to_dict(self):
        return self.dict(by_alias=True, exclude={}, exclude_none=True)

    @classmethod
    def from_json(cls, json_str: str) -> AcAChoice:
        return cls.from_dict(json.loads(json_str))

    @classmethod
    def from_dict(cls, obj: dict) -> AcAChoice:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AcAChoice.parse_obj(obj)

        return AcAChoice.parse_obj({
            'index': obj.get('index'),
            'finish_reason': obj.get('finish_reason'),
            'message': AcARespMessage.from_dict(obj.get('message')) if obj.get('message') is not None else None
        })



import json
import pprint
from typing import Optional

from pydantic import BaseModel, StrictStr, Field

from xingchen import AcAReqFunction


class AcAReqTool(BaseModel):
    id: Optional[StrictStr] = Field(None, description="工具ID")
    type: Optional[StrictStr] = Field(None, description="工具类型, 目前只支持 function")
    function: Optional[AcAReqFunction] = Field(..., description="工具函数")

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> 'AcAReqTool':
        """Create an instance of Message from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> 'AcAReqTool':
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.parse_obj(obj)

        _obj = cls.parse_obj({
            "id": obj.get("id"),
            "type": obj.get("type"),
            "function": obj.get("function")
        })
        return _obj



# coding: utf-8

"""
角色模型参数配置
"""


from __future__ import annotations

import json
import pprint
from typing import Optional, Union

from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr


class CharacterModelParameters(BaseModel):
    """
    ModelParameters
    """
    chat_model: Optional[StrictStr] = Field(None, alias="chatModel")
    top_p: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="topP")
    max_length: Optional[StrictInt] = Field(None, alias="maxLength")
    min_length: Optional[StrictInt] = Field(None, alias="minLength")
    temperature: Optional[Union[StrictFloat, StrictInt]] = None

    __properties = ["chatModel", "topP", "maxLength", "minLength", "temperature"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CharacterModelParameters:
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CharacterModelParameters:
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CharacterModelParameters.parse_obj(obj)

        _obj = CharacterModelParameters.parse_obj({
            "chat_model": obj.get("chatModel"),
            "top_p": obj.get("topP"),
            "max_length": obj.get("maxLength"),
            "min_length": obj.get("minLength"),
            "temperature": obj.get("temperature")
        })
        return _obj





# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.base_chat_request import BaseChatRequest  # noqa: E501

class TestBaseChatRequest(unittest.TestCase):
    """BaseChatRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BaseChatRequest:
        """Test BaseChatRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BaseChatRequest`
        """
        model = BaseChatRequest()  # noqa: E501
        if include_optional:
            return BaseChatRequest(
                model = '',
                parameters = xingchen.models.model_parameter.ModelParameters(
                    top_p = 1.337, 
                    top_k = 56, 
                    seed = 56, 
                    max_length = 56, 
                    temperature = 1.337, ),
                input = xingchen.models.input.Input(
                    prompt = '', 
                    messages = [
                        xingchen.models.message.Message(
                            name = '', 
                            role = '', 
                            content = '', 
                            finish_reason = '', 
                            meta = xingchen.models.meta.Meta(
                                has_risk = True, 
                                safety_std_answer = '', ), )
                        ], 
                    aca = xingchen.models.aca.aca(), ),
                servicename = '',
                debug = True
            )
        else:
            return BaseChatRequest(
                input = xingchen.models.input.Input(
                    prompt = '', 
                    messages = [
                        xingchen.models.message.Message(
                            name = '', 
                            role = '', 
                            content = '', 
                            finish_reason = '', 
                            meta = xingchen.models.meta.Meta(
                                has_risk = True, 
                                safety_std_answer = '', ), )
                        ], 
                    aca = xingchen.models.aca.aca(), ),
        )
        """

    def testBaseChatRequest(self):
        """Test BaseChatRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
